=====
Usage
=====

To use pip2amch in a project::

  pip2amch --tag my-project requirements.txt | amch push

This will push all requirements from the file to the service
https://allmychanges.com, where you can subscribe on their
release notes.
